lm.component('pageAppMap', {
	templateUrl: 'comp/page/pageAppMap.' + lmCacheTag + 'html',
	bindings: {

	},
	$canActivate: function($nextInstruction, $prevInstruction, serviceLimboMedia) {
		return serviceLimboMedia.isAuthenticated();
	},
	controller: function($scope, $http,serviceLimboMedia,serviceNotification,serviceDeps) {
		var ctrl = this;

		ctrl.paramFileId = null;
		ctrl.paramFolderId = null;

		ctrl.loadedFiles = false;
		ctrl.files = [];

		ctrl.loadedMap = false;
		ctrl.map = null;
		ctrl.clusterGroup = null;
		ctrl.markers = [];
		
		// server configured values
		ctrl.cfgTilesUrl = lmMapUrl;
		ctrl.cfgTilesAtt = lmMapAttribution;
		ctrl.cfgTilesWarn = lmMapWarning;

		ctrl.$postLink = function() {
			serviceDeps.load("leaflet").then(function() {

				ctrl.map = L.map('map', {
				    center: [50,0],
				    zoom: 3,
				    zoomControl: false
				});

				L.control.zoom({position:'topright'}).addTo(ctrl.map);
				
				L.tileLayer(ctrl.cfgTilesUrl, {attribution: ctrl.cfgTilesAtt}).addTo(ctrl.map);

				ctrl.loadedMap = true;
				ctrl.renderIt();
			});
		};

		ctrl.$routerOnActivate = function(next) {
			ctrl.paramFileId = next.params.fileId;
			ctrl.paramFolderId = next.params.folderId;
			ctrl.loadFiles();
		};

		ctrl.loadFiles = function() {
			if(ctrl.paramFileId) {
				$http.get(lmBase.url + 'f/file/' + ctrl.paramFileId + '?details=true').then(
					function success(resp) {
						ctrl.files.push(resp.data);
						ctrl.loadedFiles = true;
						ctrl.renderIt();
					}, serviceLimboMedia.handleHttpErrorNew
				);
			}
			if(ctrl.paramFolderId) {
				$http.get(lmBase.url + 'f/files/geotagged?folder=' + ctrl.paramFolderId).then(
					function success(resp) {
						ctrl.files = resp.data;
						ctrl.loadedFiles = true;
						ctrl.renderIt();
					}, serviceLimboMedia.handleHttpErrorNew
				);
			}
		};
		
		ctrl.onMarkerClick = function(e) {
			var marker = e.layer;
			var valueFile = marker.lmFile;
			var content = '<img src="X_IMG_URL"><div class="lm-popup-filename">X_FILENAME</div>';
			
			content = content.replace('X_IMG_URL','api/f/streamImage/' + valueFile.id + '/THUMB_L/x.jpg');
			content = content.replace('X_FILENAME',valueFile.name);

			var popup = L.popup()
    		popup.setContent(content);
    		marker.bindPopup(popup).openPopup();
		};
		
		ctrl.renderIt = function() {
			if(!(ctrl.loadedMap && ctrl.loadedFiles)) {
				return;
			}

			ctrl.clusterGroup = L.markerClusterGroup();
			ctrl.clusterGroup.on("click", ctrl.onMarkerClick);

			ctrl.markers = ctrl.files
				.filter(x => ('IMAGE' == x.type && (x.locX != 0 || x.locY != 0)))
				.map(x => {
					var marker = L.marker([x.locY, x.locX]);
					marker.lmFile = x;
					return marker;
				});
			
			if(ctrl.markers.length == 0) {
				serviceNotification.error('MSG_NO_GEOTAG');
			}
			else {
				ctrl.clusterGroup.addLayers(ctrl.markers);
	  			ctrl.map.addLayer(ctrl.clusterGroup);
			}
			
		};
	  
	}
});